@@ -6,6 +6,7 @@ import re
 import subprocess
 from collections import defaultdict, OrderedDict
 from datetime import datetime
+from . import conditional
 from . import config
 from . import dfnpanels
 from .refs import utils as refUtils
@@ -14,6 +15,21 @@ from .h import *
 from .messages import *
 
 
+def boilerplateFromHtml(doc, htmlString):
+    htmlString = doc.fixText(htmlString)
+    bp = E.div({}, parseHTML(htmlString))
+    conditional.processConditionals(bp, doc)
+    return childNodes(bp, clear=True)
+
+
+def loadBoilerplate(doc, filename, bpname=None):
+    if bpname is None:
+        bpname = filename
+    html = config.retrieveBoilerplateFile(doc, filename)
+    el = boilerplateFromHtml(doc, html)
+    fillWith(bpname, el, doc=doc)
+
+
 def addBikeshedVersion(doc):
     # Adds a <meta> containing the current Bikeshed semver.
     if "generator" not in doc.md.boilerplate:
@@ -123,33 +139,16 @@ def getFillContainer(tag, doc, default=False):
 
 
 def addLogo(doc):
-    html = config.retrieveBoilerplateFile(doc, 'logo')
-    html = doc.fixText(html)
-    fillWith('logo', parseHTML(html), doc=doc)
+    loadBoilerplate(doc, 'logo')
 
-def addSubstatus(doc):
-    container = getFillContainer("substatus", doc, default=False)
-    if container is None:
-        return
-    if doc.md.status == "w3c/CR":
-        appendChild(container, E.span("Snapshot"))
-    elif doc.md.status == "w3c/CRD":
-        appendChild(container, E.span("Draft"))
-    else:
-        if container is not None:
-            removeNode(container)
 
 def addCopyright(doc):
-    html = config.retrieveBoilerplateFile(doc, 'copyright')
-    html = doc.fixText(html)
-    fillWith('copyright', parseHTML(html), doc=doc)
+    loadBoilerplate(doc, 'copyright')
 
 
 def addAbstract(doc):
     if not doc.md.noAbstract:
-        html = config.retrieveBoilerplateFile(doc, 'abstract')
-        html = doc.fixText(html)
-        fillWith('abstract', parseHTML(html), doc=doc)
+        loadBoilerplate(doc, 'abstract')
     else:
         container = getFillContainer("abstract", doc, default=False)
         if container is not None:
@@ -157,9 +156,7 @@ def addAbstract(doc):
 
 
 def addStatusSection(doc):
-    html = config.retrieveBoilerplateFile(doc, 'status')
-    html = doc.fixText(html)
-    fillWith('status', parseHTML(html), doc=doc)
+    loadBoilerplate(doc, 'status')
 
 
 def addExpiryNotice(doc):
@@ -170,9 +167,7 @@ def addExpiryNotice(doc):
     else:
         boilerplate = "warning-expires"
         doc.extraScripts['script-expires'] = expiryScript
-    html = config.retrieveBoilerplateFile(doc, boilerplate)
-    html = doc.fixText(html)
-    fillWith('warning', parseHTML(html), doc=doc)
+    loadBoilerplate(doc, boilerplate, 'warning')
     addClass(doc.body, boilerplate)
 
 expiryScript = '''
@@ -190,9 +185,7 @@ if(expires < today) {
 
 def addObsoletionNotice(doc):
     if doc.md.warning:
-        html = config.retrieveBoilerplateFile(doc, doc.md.warning[0])
-        html = doc.fixText(html)
-        fillWith('warning', parseHTML(html), doc=doc)
+        loadBoilerplate(doc, doc.md.warning[0], 'warning')
 
 
 def addAtRisk(doc):
@@ -229,35 +222,37 @@ def removeUnwantedBoilerplate(doc):
 def addAnnotations(doc):
     if doc.md.vshortname in doc.testSuites:
         html = config.retrieveBoilerplateFile(doc, 'annotations')
-        html = doc.fixText(html)
-        appendContents(find("head", doc), parseHTML(html))
+        el = boilerplateFromHtml(doc, html)
+        appendContents(find("head", doc), el)
 
 
+def w3cStylesheetInUse(doc):
+    return doc.md.prepTR or doc.md.status in config.snapshotStatuses
+
+
+def keyFromStyles(kv):
+    k = kv[0]
+    if k == "style-darkmode":
+        prio = 2
+    else:
+        prio = 1
+
+    return (prio, k)
+
 def addBikeshedBoilerplate(doc):
-    for k,v in sorted(doc.extraStyles.items()):
+    w3cStylesheet = w3cStylesheetInUse(doc)
+    for k,v in sorted(doc.extraStyles.items(), key=keyFromStyles):
         if k not in doc.md.boilerplate:
             continue
-        if k == "style-darkmode":
-            # Have to output these *last* so they'll override preceding colors.
+        if w3cStylesheet and k in ["style-colors", "style-darkmode"]:
+            # These are handled by the /TR stylesheet, so don't output them
             continue
         container = getFillContainer(k, doc)
         if container is None:
             container = getFillContainer("bs-styles", doc, default=True)
         if container is not None:
             appendChild(container,
-                        E.style("/* {0} */\n".format(k) + v))
-    # Output the darkmode styles after all other styles
-    # but don't put them in /TR space yet,
-    # until the W3C is ready for them.
-    if "style-darkmode" in doc.md.boilerplate and not doc.md.prepTR:
-        k = "style-darkmode"
-        v = doc.extraStyles[k]
-        container = getFillContainer(k, doc)
-        if container is None:
-            container = getFillContainer("bs-styles", doc, default=True)
-        if container is not None:
-            appendChild(container,
-                        E.style("/* {0} */\n".format(k) + v))
+                        E.style(f"/* {k} */\n{v}"))
     for k,v in sorted(doc.extraScripts.items()):
         if k not in doc.md.boilerplate:
             continue
@@ -266,7 +261,7 @@ def addBikeshedBoilerplate(doc):
             container = getFillContainer("bs-scripts", doc, default=True)
         if container is not None:
             appendChild(container,
-                        E.script("/* {0} */\n".format(k) + v))
+                        E.script(f"/* {k} */\n{v}"))
 
 
 def addIndexSection(doc):
